package cn.estsh.i3plus.core.apiservice.serviceimpl.busi;

import cn.estsh.i3plus.core.api.iservice.busi.ISysMessageService;
import cn.estsh.i3plus.core.apiservice.mq.I3CoreQueueConfig;
import cn.estsh.i3plus.pojo.base.bean.ListPager;
import cn.estsh.i3plus.pojo.base.common.Pager;
import cn.estsh.i3plus.pojo.base.common.PagerHelper;
import cn.estsh.i3plus.pojo.base.enumutil.ImppEnumUtil;
import cn.estsh.i3plus.pojo.platform.bean.SysMessage;
import cn.estsh.i3plus.pojo.platform.bean.SysRefUserMessage;
import cn.estsh.i3plus.pojo.platform.repository.SysMessageRepository;
import cn.estsh.i3plus.pojo.platform.repository.SysRefUserMessageRepository;
import cn.estsh.i3plus.pojo.platform.repository.SysUserRepository;
import cn.estsh.i3plus.pojo.platform.sqlpack.CoreHqlPack;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.amqp.rabbit.core.RabbitTemplate;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * @Description : 消息服务接口实现
 * @Reference :
 * @Author : yunhao
 * @Date : 2018-10-25 18:02
 * @Modify :
 **/
@Service
public class SysMessageService implements ISysMessageService {

    public static final Logger LOGGER = LoggerFactory.getLogger(SysMessageService.class);

    @Autowired
    private SysMessageRepository sysMessageRDao;

    @Autowired
    private SysRefUserMessageRepository refUserMessageRDao;

    @Autowired
    private SysUserRepository sysUserRDao;

    /**
     * rabbitMQ队列
     */
    @Autowired
    private RabbitTemplate rabbitTemplate;

    @Override
    public SysMessage insertSysMessage(SysMessage sysMessage) {
        return sysMessageRDao.insert(sysMessage);
    }

    @Override
    public void deleteSysMessageById(Long id) {
        LOGGER.info("消息 SYS_MESSAGE id:{}",id);
        refUserMessageRDao.deleteByProperty("messageId",id);
        sysMessageRDao.deleteById(id);
    }

    @Override
    public void updateSysMessage(SysMessage sysMessage){
        LOGGER.info("消息 SYS_MESSAGE :{}",sysMessage);
        sysMessageRDao.update(sysMessage);
    }

    @Override
    public List<SysMessage> listSysMessage(){
        LOGGER.info("消息 SYS_MESSAGE list");
        return sysMessageRDao.list();
    }

    @Override
    public SysMessage getSysMessageById(Long id) {
        LOGGER.info("消息 SYS_MESSAGE id:{}",id);
        return sysMessageRDao.getById(id);
    }

    @Override
    public ListPager querySysMessageByPager(SysMessage sysMessage, Pager pager) {
        LOGGER.info("消息 SYS_MESSAGE SysMessage:{}，Pager:{}",sysMessage,pager);
        if(sysMessage == null) {
            pager = PagerHelper.getPager(pager, sysMessageRDao.listCount());
            return new ListPager(sysMessageRDao.listPager(pager),pager);
        }else {
            String hqlPack = CoreHqlPack.packHqlSysMessage(sysMessage);
            pager = PagerHelper.getPager(pager, sysMessageRDao.findByHqlWhereCount(hqlPack));
            return new ListPager(sysMessageRDao.findByHqlWherePage(hqlPack + sysMessage.orderBy(),pager),pager);
        }
    }

//    @Override
//    public void updateSysMessageStatusById(String id, Integer status) {
//        LOGGER.info("消息 SYS_MESSAGE id:{}，status:{}",id,status);
//        sysMessageRDao.updateByProperties("id",Long.parseLong(id),"messageStatusId", status);
//    }

    @Override
    public void deleteSysMessageByIds(Long[] ids) {
        LOGGER.info("消息 SYS_MESSAGE ids:{}", ids.toString());
        sysMessageRDao.deleteByIds(ids);
    }

//    @Override
//    public void updateSysMessageStatusByIds(String[] ids,Integer status) {
//        LOGGER.info("消息 SYS_MESSAGE ids：{}，status：{}",ids,status);
//        StringBuffer where = new StringBuffer();
//        HqlPack.getInPack(String.join(",", ids), "id", where);
//
//        sysMessageRDao.updateByHqlWhere(where.toString(), "messageStatusId", status);
//    }

    @Override
    public SysRefUserMessage insertSysRefUserMessage(SysRefUserMessage refUserMessage) {
        return refUserMessageRDao.insert(refUserMessage);
    }

    @Override
    public void doSendSysMessage(SysMessage sysMessage) {
        // 判断消息类型推送到对应的队列
        if(ImppEnumUtil.MESSAGE_TYPE.MAIL.getValue() == sysMessage.getMessageType().intValue()){
            rabbitTemplate.convertAndSend(I3CoreQueueConfig.IMPP_MESSAGE_MAIL_QUEUE,sysMessage);
        }else{
            rabbitTemplate.convertAndSend(I3CoreQueueConfig.IMPP_MESSAGE_LETTER_QUEUE,sysMessage);
        }
    }
}
