package cn.estsh.i3plus.core.apiservice.serviceimpl.busi;

import cn.estsh.i3plus.core.api.iservice.busi.ISysToolService;
import cn.estsh.i3plus.pojo.base.bean.ListPager;
import cn.estsh.i3plus.pojo.base.common.Pager;
import cn.estsh.i3plus.pojo.base.common.PagerHelper;
import cn.estsh.i3plus.pojo.base.tool.HqlPack;
import cn.estsh.i3plus.pojo.platform.bean.SysTool;
import cn.estsh.i3plus.pojo.platform.bean.SysToolType;
import cn.estsh.i3plus.pojo.platform.repository.SysToolRepository;
import cn.estsh.i3plus.pojo.platform.repository.SysToolTypeRepository;
import cn.estsh.i3plus.pojo.platform.sqlpack.CoreHqlPack;
import cn.estsh.impp.framework.boot.util.ValidatorBean;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * @Description : 硬件服务接口实现
 * @Reference :
 * @Author : yunhao
 * @Date : 2018-10-25 20:29
 * @Modify :
 **/
@Service
public class SysToolService implements ISysToolService {
    public static final Logger LOGGER = LoggerFactory.getLogger(SysToolService.class);

    @Autowired
    private SysToolRepository toolRDao;

    @Autowired
    private SysToolTypeRepository toolTypeRDao;

    @Override
    public SysTool insertSysTool(SysTool tool) {
        // 查询硬件类型名称
        LOGGER.info("硬件类型 TOOL_TYPE :{}", tool);
        SysToolType toolType = toolTypeRDao.getById(tool.getToolTypeId());
        ValidatorBean.checkNotNull(toolType);

        tool.setToolTypeNameRdd(toolType.getName());

        LOGGER.info("硬件 TOOL tool:{}",tool);
        return toolRDao.insert(tool);
    }

    @Override
    public void deleteSysToolById(Long id) {
        LOGGER.info("硬件 TOOL id:{}",id);
        toolRDao.deleteById(id);
    }

    @Override
    public void updateSysTool(SysTool tool) {
        // 查询硬件类型名称
        LOGGER.info("硬件类型 TOOL_TYPE :{}", tool);
        SysToolType toolType = toolTypeRDao.getById(tool.getToolTypeId());
        ValidatorBean.checkNotNull(toolType);

        tool.setToolTypeNameRdd(toolType.getName());

        LOGGER.info("硬件 TOOL :{}",tool);
        toolRDao.update(tool);
    }

    @Override
    public List<SysTool> listSysTool() {
        LOGGER.info("硬件 TOOL list");
        return toolRDao.list();
    }

    @Override
    public SysTool getSysToolById(Long id) {
        LOGGER.info("硬件 TOOL id:{}",id);
        return toolRDao.getById(id);
    }

    @Override
    public ListPager querySysToolByPager(SysTool tool, Pager pager) {
        LOGGER.info("硬件 TOOL SysTool:{}，Pager:{}",tool,pager);
        if(tool == null) {
            pager = PagerHelper.getPager(pager, toolRDao.listCount());
            return new ListPager(toolRDao.listPager(pager),pager);
        }else {
            String hqlPack = CoreHqlPack.packHqlSysTool(tool);
            pager = PagerHelper.getPager(pager, toolRDao.findByHqlWhereCount(hqlPack));
            return new ListPager(toolRDao.findByHqlWherePage(hqlPack + tool.orderBy(),pager),pager);
        }
    }

    @Override
    public void updateSysToolStatusById(Long id, Integer status) {
        LOGGER.info("硬件 TOOL id:{}，status：{}",id,status);
        toolRDao.updateByProperties("id",id,"toolStatusId", status);
    }

    @Override
    public void deleteSysToolByIds(Long[] ids) {
        LOGGER.info("消息 SYS_MESSAGE ids:{}", ids.toString());
        toolRDao.deleteByIds(ids);
    }

    @Override
    public void updateSysToolStatusByIds(Long[] ids, Integer status) {
        LOGGER.info("硬件 TOOL ids：{}，status：{}",ids,status);
        StringBuffer where = new StringBuffer();
        HqlPack.getInPack(StringUtils.join( ids,","), "id", where);

        toolRDao.updateByHqlWhere(where.toString(), "toolStatusId", status);
    }
}
